==> qtsensors-opensource-src_5.7.1~20161021.orig.tar.xz: qtsensors-opensource-src-5.7.1/src/plugins/sensors/generic/generictiltsensor.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef GENERICTILTSENSOR_H
#define GENERICTILTSENSOR_H

#include <QtSensors/qsensorbackend.h>
#include <QtSensors/qtiltsensor.h>
#include <QtSensors/qaccelerometer.h>

QT_BEGIN_NAMESPACE

class GenericTiltSensor : public QSensorBackend, public QAccelerometerFilter
{
    Q_OBJECT
public:

    static char const * const id;

    GenericTiltSensor(QSensor *sensor);

    void start() Q_DECL_OVERRIDE;
    void stop() Q_DECL_OVERRIDE;

    Q_INVOKABLE void calibrate();

    bool filter(QAccelerometerReading *reading) Q_DECL_OVERRIDE;

    bool isFeatureSupported(QSensor::Feature feature) const Q_DECL_OVERRIDE;

private:
    QTiltReading m_reading;
    QAccelerometer *accelerometer;
    qreal radAccuracy;
    qreal pitch;
    qreal roll;
    qreal calibratedPitch;
    qreal calibratedRoll;
    qreal xRotation;
    qreal yRotation;
};

QT_END_NAMESPACE

#endif

==> qtsensors-opensource-src_5.15.8.orig.tar.xz: qtsensors-opensource-src-5.15.8/src/plugins/sensors/generic/generictiltsensor.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef GENERICTILTSENSOR_H
#define GENERICTILTSENSOR_H

#include <QtSensors/qsensorbackend.h>
#include <QtSensors/qtiltsensor.h>
#include <QtSensors/qaccelerometer.h>

QT_BEGIN_NAMESPACE

class GenericTiltSensor : public QSensorBackend, public QAccelerometerFilter
{
    Q_OBJECT
public:

    static char const * const id;

    GenericTiltSensor(QSensor *sensor);

    void start() override;
    void stop() override;

    Q_INVOKABLE void calibrate();

    bool filter(QAccelerometerReading *reading) override;

    bool isFeatureSupported(QSensor::Feature feature) const override;

private:
    QTiltReading m_reading;
    QAccelerometer *accelerometer;
    qreal radAccuracy;
    qreal pitch;
    qreal roll;
    qreal calibratedPitch;
    qreal calibratedRoll;
    qreal xRotation;
    qreal yRotation;
};

QT_END_NAMESPACE

#endif
